#!/usr/bin/env python
# -*- coding: utf-8 -*-

#
# This file is subject to the terms and conditions defined in
# file 'LICENSE.md', which is part of this source code package.
#

from kubernetes.models.v1beta1.CPUTargetUtilization import CPUTargetUtilization
from kubernetes.models.v1beta1.DaemonSet import DaemonSet
from kubernetes.models.v1beta1.DaemonSetSpec import DaemonSetSpec
from kubernetes.models.v1beta1.DaemonSetStatus import DaemonSetStatus
from kubernetes.models.v1beta1.Deployment import Deployment
from kubernetes.models.v1beta1.DeploymentRollback import DeploymentRollback
from kubernetes.models.v1beta1.DeploymentSpec import DeploymentSpec
from kubernetes.models.v1beta1.DeploymentStatus import DeploymentStatus
from kubernetes.models.v1beta1.DeploymentStrategy import DeploymentStrategy
from kubernetes.models.v1beta1.LabelSelector import LabelSelector
from kubernetes.models.v1beta1.LabelSelectorRequirement import LabelSelectorRequirement
from kubernetes.models.v1beta1.ReplicaSet import ReplicaSet
from kubernetes.models.v1beta1.ReplicaSetSpec import ReplicaSetSpec
from kubernetes.models.v1beta1.ReplicaSetStatus import ReplicaSetStatus
from kubernetes.models.v1beta1.RollbackConfig import RollbackConfig
from kubernetes.models.v1beta1.RollingUpdateDeployment import RollingUpdateDeployment
from kubernetes.models.v1beta1.StatefulSet import StatefulSet
from kubernetes.models.v1beta1.StatefulSetSpec import StatefulSetSpec
from kubernetes.models.v1beta1.StatefulSetStatus import StatefulSetStatus
from kubernetes.models.v1beta1.StorageClass import StorageClass
from kubernetes.models.v1beta1.SubresourceReference import SubresourceReference



#!/usr/bin/env python
# -*- coding: utf-8 -*-

#
# This file is subject to the terms and conditions defined in
# file 'LICENSE.md', which is part of this source code package.
#

from kubernetes.K8sObject import K8sObject
from kubernetes.models.v1beta1.DaemonSet import DaemonSet


class K8sDaemonSet(K8sObject):

    def __init__(self, config=None, name=None):

        super(K8sDaemonSet, self).__init__(
            config=config,
            name=name,
            obj_type='DaemonSet'
        )

    # -------------------------------------------------------------------------------------  override

    def create(self):
        super(K8sDaemonSet, self).create()
        self.get()
        return self

    def update(self):
        super(K8sDaemonSet, self).update()
        self.get()
        return self

    def list(self, pattern=None):
        ls = super(K8sDaemonSet, self).list()
        daemons = list(map(lambda x: DaemonSet(x), ls))
        if pattern is not None:
            daemons = list(filter(lambda x: pattern in x.name, daemons))
        k8s = []
        for x in daemons:
            j = K8sDaemonSet(config=self.config, name=x.name)
            j.model = x
            k8s.append(j)
        return k8s

    # -------------------------------------------------------------------------------------  get

    def get(self):
        self.model = DaemonSet(self.get_model())
        return self



#!/usr/bin/env python
# -*- coding: utf-8 -*-

#
# This file is subject to the terms and conditions defined in
# file 'LICENSE.md', which is part of this source code package.
#

from kubernetes.models.v1.AttachedVolume import AttachedVolume
from kubernetes.models.v1.ComponentCondition import ComponentCondition
from kubernetes.models.v1.ComponentStatus import ComponentStatus
from kubernetes.models.v1.ComponentStatusList import ComponentStatusList
from kubernetes.models.v1.Container import Container
from kubernetes.models.v1.ContainerImage import ContainerImage
from kubernetes.models.v1.ContainerPort import ContainerPort
from kubernetes.models.v1.ContainerStatus import ContainerStatus
from kubernetes.models.v1.DaemonEndpoint import DaemonEndpoint
from kubernetes.models.v1.DeleteOptions import DeleteOptions
from kubernetes.models.v1.ExecAction import ExecAction
from kubernetes.models.v1.HTTPGetAction import HTTPGetAction
from kubernetes.models.v1.LoadBalancerIngress import LoadBalancerIngress
from kubernetes.models.v1.LoadBalancerStatus import LoadBalancerStatus
from kubernetes.models.v1.Namespace import Namespace
from kubernetes.models.v1.NamespaceSpec import NamespaceSpec
from kubernetes.models.v1.NamespaceStatus import NamespaceStatus
from kubernetes.models.v1.Node import Node
from kubernetes.models.v1.NodeAddress import NodeAddress
from kubernetes.models.v1.NodeCondition import NodeCondition
from kubernetes.models.v1.NodeDaemonEndpoints import NodeDaemonEndpoints
from kubernetes.models.v1.NodeList import NodeList
from kubernetes.models.v1.NodeStatus import NodeStatus
from kubernetes.models.v1.NodeSpec import NodeSpec
from kubernetes.models.v1.NodeSystemInfo import NodeSystemInfo
from kubernetes.models.v1.ObjectMeta import ObjectMeta
from kubernetes.models.v1.PersistentVolumeSpec import PersistentVolumeSpec
from kubernetes.models.v1.Pod import Pod
from kubernetes.models.v1.PodCondition import PodCondition
from kubernetes.models.v1.PodSpec import PodSpec
from kubernetes.models.v1.PodStatus import PodStatus
from kubernetes.models.v1.PodTemplateSpec import PodTemplateSpec
from kubernetes.models.v1.Probe import Probe
from kubernetes.models.v1.ReplicationController import ReplicationController
from kubernetes.models.v1.ReplicationControllerSpec import ReplicationControllerSpec
from kubernetes.models.v1.ReplicationControllerStatus import ReplicationControllerStatus
from kubernetes.models.v1.ResourceRequirements import ResourceRequirements
from kubernetes.models.v1.Secret import Secret
from kubernetes.models.v1.SecurityContext import SecurityContext
from kubernetes.models.v1.Service import Service
from kubernetes.models.v1.ServicePort import ServicePort
from kubernetes.models.v1.ServiceSpec import ServiceSpec
from kubernetes.models.v1.ServiceStatus import ServiceStatus
from kubernetes.models.v1.TCPSocketAction import TCPSocketAction
from kubernetes.models.v1.Volume import Volume
from kubernetes.models.v1.VolumeMount import VolumeMount
